==> ckan-2.8.5.tar.gz: ckan-2.8.5/ckan/public/base/i18n/ko_KR.js <==
{
  "": {
    "domain": "ckan", 
    "lang": "ko_KR", 
    "plural-forms": "nplurals=1; plural=0;"
  }, 
  "%(color)s shirt": [
    "%(color)s shirts", 
    ""
  ], 
  "%(num)d item": [
    "%(num)d items", 
    ""
  ], 
  "%(num)d missing translation": [
    "%(num)d missing translations", 
    ""
  ], 
  "Add Filter": [
    null, 
    "필터 추가"
  ], 
  "An Error Occurred": [
    null, 
    "오류 발생"
  ], 
  "Are you sure you want to perform this action?": [
    null, 
    "이 작업의 수행을 원합니까?"
  ], 
  "Cancel": [
    null, 
    "취소"
  ], 
  "Confirm": [
    null, 
    "승인"
  ], 
  "Could not load view": [
    null, 
    "뷰를 로드할 수 없음"
  ], 
  "DataProxy returned an error": [
    null, 
    "데이터프록시에서 오류를 반환하였습니다."
  ], 
  "DataStore returned an error": [
    null, 
    "데이터스토어에서 오류를 반환함"
  ], 
  "Edit": [
    null, 
    "편집"
  ], 
  "Failed to load data API information": [
    null, 
    "데이터 API 정보를 읽어오는데 실패했습니다"
  ], 
  "File": [
    null, 
    "파일"
  ], 
  "Filters": [
    null, 
    "필터"
  ], 
  "Follow": [
    null, 
    "Follow"
  ], 
  "Graph": [
    null, 
    "그래프"
  ], 
  "Grid": [
    null, 
    "그리드"
  ], 
  "Hide": [
    null, 
    "숨기기"
  ], 
  "Image": [
    null, 
    "이미지"
  ], 
  "Input is too short, must be at least one character": [
    "Input is too short, must be at least %(num)d characters", 
    "입력이 너무 짧아요, 최소한 %(num)d 이상으로 입력해주세요"
  ], 
  "Link": [
    null, 
    "링크"
  ], 
  "Link to a URL on the internet (you can also link to an API)": [
    null, 
    "인터넷에 있는 URL 연결 (API 연결도 가능)"
  ], 
  "Loading...": [
    null, 
    "로딩중…"
  ], 
  "Map": [
    null, 
    "지도"
  ], 
  "No matches found": [
    null, 
    "일치하는 것을 찾을 수 없음"
  ], 
  "Please Confirm Action": [
    null, 
    "작업을 승인해 주세요"
  ], 
  "Remove": [
    null, 
    "제거"
  ], 
  "Resource uploaded": [
    null, 
    "리소스가 업로드 되었음"
  ], 
  "Save order": [
    null, 
    "순서 저장"
  ], 
  "Saving...": [
    null, 
    "저장 중"
  ], 
  "Select a field": [
    null, 
    "필드 선택하기"
  ], 
  "Show more": [
    null, 
    "더 보기"
  ], 
  "Start typing…": [
    null, 
    "타이핑 시작..."
  ], 
  "There are unsaved modifications to this form": [
    null, 
    "이 양식에 저장되지 않은 변경사항이 있습니다."
  ], 
  "There is no API data to load for this resource": [
    null, 
    "이 리소스를 적재할 API 데이터가 없음"
  ], 
  "URL": [
    null, 
    "URL"
  ], 
  "Unable to authenticate upload": [
    null, 
    "업로드를 인증할 수 없습니다"
  ], 
  "Unable to get data for uploaded file": [
    null, 
    "파일을 업로드하기 위한 데이터를 가져올 수 없음"
  ], 
  "Unable to upload file": [
    null, 
    "파일 업로드 불가"
  ], 
  "Unfollow": [
    null, 
    "Unfollow"
  ], 
  "Upload": [
    null, 
    "업로드"
  ], 
  "Upload a file": [
    null, 
    "파일 업로드하기"
  ], 
  "Upload a file on your computer": [
    null, 
    "컴퓨터에 있는 파일을 업로드하기"
  ], 
  "You are uploading a file. Are you sure you want to navigate away and stop this upload?": [
    null, 
    "파일을 업로드중입니다. 탐색을 위해 업로드를 중지하겠습니까?"
  ], 
  "bar": [
    "bars", 
    ""
  ], 
  "error loading view": [
    null, 
    "오류 로딩 뷰"
  ], 
  "no %(attr)s translation": [
    "no %(attr)s translations", 
    ""
  ], 
  "no translation": [
    "no translations", 
    ""
  ]
}

==> ckan-2.9.9.tar.gz: ckan-2.9.9/ckan/public/base/i18n/ko_KR.js <==
{
  "": {
    "domain": "ckan",
    "lang": "ko_KR",
    "plural-forms": "nplurals=1; plural=0;"
  },
  "Add Filter": [
    null,
    "필터 추가"
  ],
  "An Error Occurred": [
    null,
    "오류 발생"
  ],
  "An error occured during AJAX request. Could not load view.": [
    null,
    "AJAX 요청을 처리하는 중에 오류가 발생했습니다. 뷰를 읽을 수 없습니다."
  ],
  "Are you sure you want to perform this action?": [
    null,
    "이 작업의 수행을 원합니까?"
  ],
  "Cancel": [
    null,
    "취소"
  ],
  "Confirm": [
    null,
    "승인"
  ],
  "Could not load view": [
    null,
    "뷰를 로드할 수 없음"
  ],
  "DataProxy returned an error": [
    null,
    "데이터프록시에서 오류를 반환하였습니다."
  ],
  "DataStore returned an error": [
    null,
    "데이터스토어에서 오류를 반환함"
  ],
  "Edit": [
    null,
    "편집"
  ],
  "Failed to load data API information": [
    null,
    "데이터 API 정보를 읽어오는데 실패했습니다"
  ],
  "File": [
    null,
    "파일"
  ],
  "Filters": [
    null,
    "필터"
  ],
  "Follow": [
    null,
    "Follow"
  ],
  "Graph": [
    null,
    "그래프"
  ],
  "Grid": [
    null,
    "그리드"
  ],
  "Hide": [
    null,
    "숨기기"
  ],
  "Image": [
    null,
    "이미지"
  ],
  "Input is too short, must be at least one character": [
    "Input is too short, must be at least %(num)d characters",
    "입력이 너무 짧아요, 최소한 %(num)d 이상으로 입력해주세요"
  ],
  "Link": [
    null,
    "링크"
  ],
  "Link to a URL on the internet (you can also link to an API)": [
    null,
    "인터넷에 있는 URL 연결 (API 연결도 가능)"
  ],
  "Loading...": [
    null,
    "로딩중…"
  ],
  "Map": [
    null,
    "지도"
  ],
  "No matches found": [
    null,
    "일치하는 것을 찾을 수 없음"
  ],
  "Please Confirm Action": [
    null,
    "작업을 승인해 주세요"
  ],
  "Remove": [
    null,
    "제거"
  ],
  "Resource uploaded": [
    null,
    "리소스가 업로드 되었음"
  ],
  "Save order": [
    null,
    "순서 저장"
  ],
  "Saving...": [
    null,
    "저장 중"
  ],
  "Select a field": [
    null,
    "필드 선택하기"
  ],
  "Show more": [
    null,
    "더 보기"
  ],
  "Start typing…": [
    null,
    "타이핑 시작..."
  ],
  "There are unsaved modifications to this form": [
    null,
    "이 양식에 저장되지 않은 변경사항이 있습니다."
  ],
  "There is no API data to load for this resource": [
    null,
    "이 리소스를 적재할 API 데이터가 없음"
  ],
  "URL": [
    null,
    "URL"
  ],
  "Unable to authenticate upload": [
    null,
    "업로드를 인증할 수 없습니다"
  ],
  "Unable to get data for uploaded file": [
    null,
    "파일을 업로드하기 위한 데이터를 가져올 수 없음"
  ],
  "Unable to upload file": [
    null,
    "파일 업로드 불가"
  ],
  "Unfollow": [
    null,
    "Unfollow"
  ],
  "Upload": [
    null,
    "업로드"
  ],
  "Upload a file": [
    null,
    "파일 업로드하기"
  ],
  "Upload a file on your computer": [
    null,
    "컴퓨터에 있는 파일을 업로드하기"
  ],
  "You are uploading a file. Are you sure you want to navigate away and stop this upload?": [
    null,
    "파일을 업로드중입니다. 탐색을 위해 업로드를 중지하겠습니까?"
  ],
  "error loading view": [
    null,
    "오류 로딩 뷰"
  ]
}
